
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.032.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use Local::ModuleBuild;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28",
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  },
  "configure_requires" => {
    "Module::Build" => "0.28",
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  },
  "dist_abstract" => "Perl-based open notation for data",
  "dist_author" => [
    "Andrew Main (Zefram) <zefram\@fysh.org>"
  ],
  "dist_name" => "Data-Pond",
  "dist_version" => "0.006",
  "license" => "perl",
  "module_name" => "Data::Pond",
  "recommends" => {
    "XSLoader" => 0
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Exporter" => 0,
    "Params::Classify" => 0,
    "parent" => 0,
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "Test::More" => 0,
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "perl" => "5.008",
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Local::ModuleBuild->new(%module_build_args);


$build->create_build_script;
